@@ -15,6 +15,7 @@ from .exceptions import (
     ConnectionClosed,
     ConnectionFailed,
     FailedCommand,
+    FailedZWaveCommand,
     InvalidMessage,
     InvalidServerVersion,
     InvalidState,
@@ -29,7 +30,12 @@ SIZE_PARSE_JSON_EXECUTOR = 8192
 class Client:
     """Class to manage the IoT connection."""
 
-    def __init__(self, ws_server_url: str, aiohttp_session: ClientSession):
+    def __init__(
+        self,
+        ws_server_url: str,
+        aiohttp_session: ClientSession,
+        schema_version: int = MAX_SERVER_SCHEMA_VERSION,
+    ):
         """Initialize the Client class."""
         self.ws_server_url = ws_server_url
         self.aiohttp_session = aiohttp_session
@@ -38,7 +44,7 @@ class Client:
         self._client: Optional[ClientWebSocketResponse] = None
         # Version of the connected server
         self.version: Optional[VersionInfo] = None
-        self.schema_version: int = MAX_SERVER_SCHEMA_VERSION
+        self.schema_version: int = schema_version
         self._logger = logging.getLogger(__package__)
         self._loop = asyncio.get_running_loop()
         self._result_futures: Dict[str, asyncio.Future] = {}
@@ -133,6 +139,26 @@ class Client:
             self.schema_version,
         )
 
+    async def set_api_schema(self) -> None:
+        """Set API schema version on server."""
+        assert self._client
+
+        # set preferred schema version on the server
+        # note: we already check for (in)compatible schemas in the connect call
+        await self._send_json_message(
+            {
+                "command": "set_api_schema",
+                "messageId": "api-schema-id",
+                "schemaVersion": self.schema_version,
+            }
+        )
+        set_api_msg = await self._receive_json_or_raise()
+
+        if not set_api_msg["success"]:
+            # this should not happen, but just in case
+            await self._client.close()
+            raise FailedCommand(set_api_msg["messageId"], set_api_msg["errorCode"])
+
     async def listen(self, driver_ready: asyncio.Event) -> None:
         """Start listening to the websocket."""
         if not self.connected:
@@ -141,21 +167,21 @@ class Client:
         assert self._client
 
         try:
-            # set preferred schema version on the server
-            # note: we already check for (in)compatible schemas in the connect call
+            await self.set_api_schema()
+
             await self._send_json_message(
                 {
-                    "command": "set_api_schema",
-                    "messageId": "api-schema-id",
-                    "schemaVersion": self.schema_version,
+                    "command": "driver.get_log_config",
+                    "messageId": "get-initial-log-config",
                 }
             )
-            set_api_msg = await self._receive_json_or_raise()
 
-            if not set_api_msg["success"]:
-                # this should not happen, but just in case
+            log_msg = await self._receive_json_or_raise()
+
+            # this should not happen, but just in case
+            if not log_msg["success"]:
                 await self._client.close()
-                raise FailedCommand(set_api_msg["messageId"], set_api_msg["errorCode"])
+                raise FailedCommand(log_msg["messageId"], log_msg["errorCode"])
 
             # send start_listening command to the server
             # we will receive a full state dump and from now on get events
@@ -172,7 +198,11 @@ class Client:
             self.driver = cast(
                 Driver,
                 await self._loop.run_in_executor(
-                    None, Driver, self, state_msg["result"]["state"]
+                    None,
+                    Driver,
+                    self,
+                    state_msg["result"]["state"],
+                    log_msg["result"]["config"],
                 ),
             )
 
@@ -262,7 +292,14 @@ class Client:
                 future.set_result(msg["result"])
                 return
 
-            future.set_exception(FailedCommand(msg["messageId"], msg["errorCode"]))
+            if msg["errorCode"] != "zwave_error":
+                err = FailedCommand(msg["messageId"], msg["errorCode"])
+            else:
+                err = FailedZWaveCommand(
+                    msg["messageId"], msg["zwaveErrorCode"], msg["zwaveErrorMessage"]
+                )
+
+            future.set_exception(err)
             return
 
         if msg["type"] != "event":
